

## Documentation

- In each file, add an example of usage

## Document Library Philosophy and Intended Usage

### Module docstring format:

- Purpose of module, intended usage e.g. 1D convolution layer designed for convolving over sequences
- Initialisation and call example.
- Try to keep minimal.

## Demos

### CV
- CNN on MNIST
- UNET medical image segmentation

### Sequence modelling
- RNN demo on Sequential MNIST
- SSM on Pathfinder dataset
- BERT on IMDB movie reviews w att viz
- NMT pig latin to english translation char level 

### Generative modelling
- DCGAN on Stanford Dogs
- Transformer decoder on TinyStories
- Diffusion on Oxford Flowers
- VAE on dSprites with interactive plot

### RL
- DQN on Atari (classic)
- AlphaZero on chess (flex)

### Other
- Siamese networks Omniglot
- Pointer network with convex hull problem


- Solving a PI problem with deep sets/set transformers
- MinLSTM and MinGRU AR memory tasks?
- Vision transformer on something
- SAC on Brax?
- PPO on something interesting
- LoRA to speak like yoda maybe?
- Molecule problems for rotational invariance with GNNs?

- Fine-tuning and freezing
- Model surgery
- Reduced precision
- Distil big model into small?

- Deep Dream could be cool?

- Octax?

### Blocks

- Set transformers
- Pointer network
- Deep sets
- PI?
- GNN?


- Test pip install works
- Why use Ion?